Learn R Programming

rmcfs (version 1.2.5)

alizadeh: Loads sample data from a lymphoma/leukemia gene expression study

Description

The sample data for the MCFS-ID algorithm

Usage

data(alizadeh)

Arguments

Format

A 4026 x 62 gene expression data matrix of log-ratio values. The last column contains the annotations of the 62 samples with respect to the cancer types C, D, F.