Learn R Programming

rmcfs (version 1.2.6)

refine.data: Filters input data

Description

Selects columns from input data based on the highest RIs of attributes.

Usage

refine.data(data, mcfs_result, size = NA)

Arguments

data

input data.frame.

mcfs_result

result from mcfs function.

size

number of top features to select from input data. If size = NA, then it is defined by mcfs_result$cutoff_value parameter.

Value

data.frame with selected columns.

Examples

Run this code
# NOT RUN {
  # create input data
  adata <- artificial.data(rnd_features = 10)
  showme(adata)
  
  # Parametrize and run MCFS-ID procedure
  result <- mcfs(class~., adata, cutoffPermutations = 0, featureFreq = 10,
                  finalCV = FALSE, finalRuleset = FALSE, threadsNumber = 2)

  head(refine.data(adata, result, size = result$cutoff_value))
# }

Run the code above in your browser using DataLab